@@ -7,19 +7,19 @@
  * Copyright 2001, 2002, 2003 Ximian, Inc.
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #define _GNU_SOURCE
@@ -413,14 +413,6 @@ _atk_bridge_register_application (gpointer data)
 
   spi_global_app_data->registration_pending = 0;
 
-  g_free (app->desktop_name);
-  g_free (app->desktop_path);
-
-  /* These will be overridden when we get a reply, but in practice these
-     defaults should always be correct */
-  app->desktop_name = g_strdup (ATSPI_DBUS_NAME_REGISTRY);
-  app->desktop_path = g_strdup (ATSPI_DBUS_PATH_ROOT);
-
   message = dbus_message_new_method_call (SPI_DBUS_NAME_REGISTRY,
                                           ATSPI_DBUS_PATH_ROOT,
                                           ATSPI_DBUS_INTERFACE_SOCKET,
@@ -1023,6 +1015,8 @@ atk_bridge_adaptor_init (gint * argc, gchar ** argv[])
   /* Allocate global data and do ATK initializations */
   spi_global_app_data = g_new0 (SpiBridge, 1);
   spi_global_app_data->root = g_object_ref (root);
+  spi_global_app_data->desktop_name = g_strdup (ATSPI_DBUS_NAME_REGISTRY);
+  spi_global_app_data->desktop_path = g_strdup (ATSPI_DBUS_PATH_ROOT);
 
   /* Set up D-Bus connection and register bus name */
   dbus_error_init (&error);
